[gimp] libgimp*: fix some parameter inconsistencies to silence GI warnings



commit c08186e6fee8e3984ec6a84c4b5332452b9fff0b
Author: Michael Natterer <mitch gimp org>
Date:   Wed Aug 7 22:05:12 2019 +0200

    libgimp*: fix some parameter inconsistencies to silence GI warnings

 libgimp/gimpplugin.h        | 6 +++---
 libgimpwidgets/gimpbutton.c | 9 +++++----
 libgimpwidgets/gimpbutton.h | 2 +-
 3 files changed, 9 insertions(+), 8 deletions(-)
---
diff --git a/libgimp/gimpplugin.h b/libgimp/gimpplugin.h
index a59bb331eb..5cc12d1184 100644
--- a/libgimp/gimpplugin.h
+++ b/libgimp/gimpplugin.h
@@ -95,8 +95,8 @@ struct _GimpPlugInClass
 
   /**
    * GimpPlugInClass::create_procedure:
-   * @plug_in: a #GimpPlugIn.
-   * @name: procedure name.
+   * @plug_in:        a #GimpPlugIn.
+   * @procedure_name: procedure name.
    *
    * This method should be overridden by all plug-ins and return a newly
    * allocated #GimpProcedure named @name.
@@ -107,7 +107,7 @@ struct _GimpPlugInClass
    *          the procedure to be registered by @plug_in.
    */
   GimpProcedure  * (* create_procedure) (GimpPlugIn  *plug_in,
-                                         const gchar *name);
+                                         const gchar *procedure_name);
 
   /**
    * GimpPlugInClass::quit:
diff --git a/libgimpwidgets/gimpbutton.h b/libgimpwidgets/gimpbutton.h
index 315ca24b81..8af62d28f7 100644
--- a/libgimpwidgets/gimpbutton.h
+++ b/libgimpwidgets/gimpbutton.h
@@ -73,7 +73,7 @@ GType       gimp_button_get_type         (void) G_GNUC_CONST;
 GtkWidget * gimp_button_new              (void);
 
 void        gimp_button_extended_clicked (GimpButton      *button,
-                                          GdkModifierType  state);
+                                          GdkModifierType  modifier_state);
 
 
 G_END_DECLS


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgimpwidgets/gimpbutton.c b/libgimpwidgets/gimpbutton.c
index 6cc8f84d74..365a9b83d7 100644
--- a/libgimpwidgets/gimpbutton.c
+++ b/libgimpwidgets/gimpbutton.c
@@ -116,18 +116,19 @@ gimp_button_new (void)
 
 /**
  * gimp_button_extended_clicked:
  * @button: a #GimpButton.
  * @state:  a state as found in #GdkEventButton->state, e.g. #GDK_SHIFT_MASK.
  *
  * Emits the button's "extended_clicked" signal.
  **/
 void
 gimp_button_extended_clicked (GimpButton      *button,
-                              GdkModifierType  state)
+                              GdkModifierType  modifier_state)
 {
   g_return_if_fail (GIMP_IS_BUTTON (button));
 
-  g_signal_emit (button, button_signals[EXTENDED_CLICKED], 0, state);
+  g_signal_emit (button, button_signals[EXTENDED_CLICKED], 0, modifier_state);
 }
 
 static gboolean
@@ -116,18 +116,19 @@ gimp_button_new (void)
 /**
  * gimp_button_extended_clicked:
- * @button: a #GimpButton.
- * @state:  a state as found in #GdkEventButton->state, e.g. #GDK_SHIFT_MASK.
+ * @button:         a #GimpButton.
+ * @modifier_state: a state as found in #GdkEventButton->state,
+ *                  e.g. #GDK_SHIFT_MASK.
  *
  * Emits the button's "extended_clicked" signal.